@@ -67,7 +67,7 @@ CONF.register_opts(opts, group='disk_utils')
 LOG = logging.getLogger(__name__)
 
 _PARTED_PRINT_RE = re.compile(r"^(\d+):([\d\.]+)MiB:"
-                              "([\d\.]+)MiB:([\d\.]+)MiB:(\w*):(.*):(.*);")
+                              "([\d\.]+)MiB:([\d\.]+)MiB:(\w*)::(\w*)")
 
 CONFIGDRIVE_LABEL = "config-2"
 MAX_CONFIG_DRIVE_SIZE_MB = 64
@@ -84,8 +84,7 @@ def list_partitions(device):
 
     :param device: The device path.
     :returns: list of dictionaries (one per partition) with keys:
-              number, start, end, size (in MiB), filesystem, partition_name,
-              flags
+              number, start, end, size (in MiB), filesystem, flags
     """
     output = utils.execute(
         'parted', '-s', '-m', device, 'unit', 'MiB', 'print',
@@ -94,8 +93,7 @@ def list_partitions(device):
         output = output.decode("utf-8")
     lines = [line for line in output.split('\n') if line.strip()][2:]
     # Example of line: 1:1.00MiB:501MiB:500MiB:ext4::boot
-    fields = ('number', 'start', 'end', 'size', 'filesystem', 'partition_name',
-              'flags')
+    fields = ('number', 'start', 'end', 'size', 'filesystem', 'flags')
     result = []
     for line in lines:
         match = _PARTED_PRINT_RE.match(line)
@@ -315,9 +313,15 @@ def is_block_device(dev):
     raise exception.InstanceDeployFailure(msg)
 
 
-def dd(src, dst):
+def dd(src, dst, conv_flags=None):
     """Execute dd from src to dst."""
-    utils.dd(src, dst, 'bs=%s' % CONF.disk_utils.dd_block_size, 'oflag=direct')
+    if conv_flags:
+        extra_args = ['conv=%s' % conv_flags]
+    else:
+        extra_args = []
+
+    utils.dd(src, dst, 'bs=%s' % CONF.disk_utils.dd_block_size, 'oflag=direct',
+             *extra_args)
 
 
 def qemu_img_info(path):
@@ -337,10 +341,10 @@ def convert_image(source, dest, out_format, run_as_root=False):
     utils.execute(*cmd, run_as_root=run_as_root, prlimit=QEMU_IMG_LIMITS)
 
 
-def populate_image(src, dst):
+def populate_image(src, dst, conv_flags=None):
     data = qemu_img_info(src)
     if data.file_format == 'raw':
-        dd(src, dst)
+        dd(src, dst, conv_flags=conv_flags)
     else:
         convert_image(src, dst, 'raw', True)
 
@@ -487,7 +491,7 @@ def _get_configdrive(configdrive, node_uuid, tempdir=None):
 def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
                  image_path, node_uuid, preserve_ephemeral=False,
                  configdrive=None, boot_option="netboot", boot_mode="bios",
-                 tempdir=None, disk_label=None, cpu_arch=""):
+                 tempdir=None, disk_label=None, cpu_arch="", conv_flags=None):
     """Create partitions and copy an image to the root partition.
 
     :param dev: Path for the device to work on.
@@ -515,6 +519,9 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
         steps will be taken. This default should be used for x86_64. When
         set to ppc64*, architecture specific steps are taken for booting a
         partition image locally.
+    :param conv_flags: Flags that need to be sent to the dd command, to control
+        the conversion of the original file when copying to the host. It can
+        contain several options separated by commas.
     :returns: a dictionary containing the following keys:
         'root uuid': UUID of root partition
         'efi system partition uuid': UUID of the uefi system partition
@@ -577,7 +584,7 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
 
         if configdrive_part:
             # Copy the configdrive content to the configdrive partition
-            dd(configdrive_file, configdrive_part)
+            dd(configdrive_file, configdrive_part, conv_flags=conv_flags)
             LOG.info("Configdrive for node %(node)s successfully copied "
                      "onto partition %(partition)s",
                      {'node': node_uuid, 'partition': configdrive_part})
@@ -588,7 +595,7 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
         if configdrive_file:
             utils.unlink_without_raise(configdrive_file)
 
-    populate_image(image_path, root_part)
+    populate_image(image_path, root_part, conv_flags=conv_flags)
     LOG.info("Image for %(node)s successfully populated",
              {'node': node_uuid})
 
@@ -861,25 +868,6 @@ def create_config_drive_partition(node_uuid, device, configdrive):
                 utils.execute('parted', '-a', 'optimal', '-s', '--', device,
                               'mkpart', 'primary', 'fat32', startlimit,
                               endlimit, run_as_root=True)
-            # Parted uses fsync to tell the kernel to sync file io
-            # however on ramdisks in ramfs, this is an explicit no-op.
-            # Explicitly call sync so when the the kernel attempts to read
-            # the partition table from disk, it is less likely that the write
-            # is still in buffer cache pending write to disk.
-            LOG.debug('Explicitly calling sync to force buffer/cache flush.')
-            utils.execute('sync')
-            # Make sure any additions to the partitioning are reflected in the
-            # kernel.
-            LOG.debug('Waiting until udev event queue is empty')
-            utils.execute('udevadm', 'settle')
-            try:
-                utils.execute('partprobe', device, run_as_root=True,
-                              attempts=CONF.disk_utils.partprobe_attempts)
-                # Also verify that the partitioning is correct now.
-                utils.execute('sgdisk', '-v', device, run_as_root=True)
-            except processutils.ProcessExecutionError as exc:
-                LOG.warning('Failed to verify GPT partitioning after creating '
-                            'the configdrive partition: %s', exc)
 
             upd_parts = set(part['number'] for part in list_partitions(device))
             new_part = set(upd_parts) - set(cur_parts)
