@@ -47,9 +47,9 @@ BYT;
 """
         expected = [
             {'number': 1, 'start': 1, 'end': 501, 'size': 500,
-             'filesystem': 'ext4', 'partition_name': '', 'flags': 'boot'},
+             'filesystem': 'ext4', 'flags': 'boot'},
             {'number': 2, 'start': 501, 'end': 476940, 'size': 476439,
-             'filesystem': '', 'partition_name': '', 'flags': ''},
+             'filesystem': '', 'flags': ''},
         ]
         execute_mock.return_value = (output, '')
         result = disk_utils.list_partitions('/dev/fake')
@@ -70,46 +70,6 @@ BYT;
         self.assertEqual(1, log_mock.call_count)
 
 
-@mock.patch.object(utils, 'execute', autospec=True)
-class ListPartitionsGPTTestCase(base.IronicLibTestCase):
-
-    def test_correct(self, execute_mock):
-        output = """
-BYT;
-/dev/vda:40960MiB:virtblk:512:512:gpt:Virtio Block Device:;
-2:1.00MiB:2.00MiB:1.00MiB::Bios partition:bios_grub;
-1:4.00MiB:5407MiB:5403MiB:ext4:Root partition:;
-3:5407MiB:5507MiB:100MiB:fat16:Boot partition:boot, esp;
-"""
-        expected = [
-            {'end': 2, 'number': 2, 'start': 1, 'flags': 'bios_grub',
-             'filesystem': '', 'partition_name': 'Bios partition', 'size': 1},
-            {'end': 5407, 'number': 1, 'start': 4, 'flags': '',
-             'filesystem': 'ext4', 'partition_name': 'Root partition',
-             'size': 5403},
-            {'end': 5507, 'number': 3, 'start': 5407,
-             'flags': 'boot, esp', 'filesystem': 'fat16',
-             'partition_name': 'Boot partition', 'size': 100},
-        ]
-        execute_mock.return_value = (output, '')
-        result = disk_utils.list_partitions('/dev/fake')
-        self.assertEqual(expected, result)
-        execute_mock.assert_called_once_with(
-            'parted', '-s', '-m', '/dev/fake', 'unit', 'MiB', 'print',
-            use_standard_locale=True, run_as_root=True)
-
-    @mock.patch.object(disk_utils.LOG, 'warning', autospec=True)
-    def test_incorrect(self, log_mock, execute_mock):
-        output = """
-BYT;
-/dev/vda:40960MiB:virtblk:512:512:gpt:Virtio Block Device:;
-2:XX1.00MiB:---:1.00MiB::primary:bios_grub;
-"""
-        execute_mock.return_value = (output, '')
-        self.assertEqual([], disk_utils.list_partitions('/dev/fake'))
-        self.assertEqual(1, log_mock.call_count)
-
-
 @mock.patch.object(disk_partitioner.DiskPartitioner, 'commit', lambda _: None)
 class WorkOnDiskTestCase(base.IronicLibTestCase):
 
@@ -242,7 +202,8 @@ class WorkOnDiskTestCase(base.IronicLibTestCase):
 
     @mock.patch.object(utils, 'mkfs', lambda fs, path, label=None: None)
     @mock.patch.object(disk_utils, 'block_uuid', lambda p: 'uuid')
-    @mock.patch.object(disk_utils, 'populate_image', lambda *_: None)
+    @mock.patch.object(disk_utils, 'populate_image', lambda image_path,
+                       root_path, conv_flags=None: None)
     def test_gpt_disk_label(self):
         ephemeral_part = '/dev/fake-part1'
         swap_part = '/dev/fake-part2'
@@ -260,7 +221,7 @@ class WorkOnDiskTestCase(base.IronicLibTestCase):
         disk_utils.work_on_disk(self.dev, self.root_mb,
                                 self.swap_mb, ephemeral_mb, ephemeral_format,
                                 self.image_path, self.node_uuid,
-                                disk_label='gpt')
+                                disk_label='gpt', conv_flags=None)
         self.assertEqual(self.mock_ibd.call_args_list, calls)
         self.mock_mp.assert_called_once_with(self.dev, self.root_mb,
                                              self.swap_mb, ephemeral_mb,
@@ -303,7 +264,7 @@ class WorkOnDiskTestCase(base.IronicLibTestCase):
         mock_mkfs.assert_called_once_with(fs='vfat', path=efi_part,
                                           label='efi-part')
         mock_populate_image.assert_called_once_with(self.image_path,
-                                                    root_part)
+                                                    root_part, conv_flags=None)
         mock_block_uuid.assert_any_call(root_part)
         mock_block_uuid.assert_any_call(efi_part)
 
@@ -349,7 +310,7 @@ class WorkOnDiskTestCase(base.IronicLibTestCase):
 
         self.mock_mp.return_value = {'PReP Boot partition': prep_part,
                                      'root': root_part}
-        self.mock_ibd.return_value = True
+        self.mock_ibd.return_vaue = True
         calls = [mock.call(root_part),
                  mock.call(prep_part)]
         disk_utils.work_on_disk(self.dev, self.root_mb,
@@ -368,6 +329,30 @@ class WorkOnDiskTestCase(base.IronicLibTestCase):
                                              cpu_arch="ppc64le")
         self.assertFalse(mock_mkfs.called)
 
+    @mock.patch.object(disk_utils, 'block_uuid', autospec=True)
+    @mock.patch.object(disk_utils, 'populate_image', autospec=True)
+    @mock.patch.object(utils, 'mkfs', autospec=True)
+    def test_convert_to_sparse(self, mock_mkfs, mock_populate_image,
+                               mock_block_uuid):
+        ephemeral_part = '/dev/fake-part1'
+        swap_part = '/dev/fake-part2'
+        root_part = '/dev/fake-part3'
+        ephemeral_mb = 256
+        ephemeral_format = 'exttest'
+
+        self.mock_mp.return_value = {'ephemeral': ephemeral_part,
+                                     'swap': swap_part,
+                                     'root': root_part}
+        self.mock_ibd.return_value = True
+        disk_utils.work_on_disk(self.dev, self.root_mb,
+                                self.swap_mb, ephemeral_mb, ephemeral_format,
+                                self.image_path, self.node_uuid,
+                                disk_label='gpt', conv_flags='sparse')
+
+        mock_populate_image.assert_called_once_with(self.image_path,
+                                                    root_part,
+                                                    conv_flags='sparse')
+
 
 @mock.patch.object(utils, 'execute', autospec=True)
 class MakePartitionsTestCase(base.IronicLibTestCase):
@@ -652,7 +637,15 @@ class PopulateImageTestCase(base.IronicLibTestCase):
         type(mock_qinfo.return_value).file_format = mock.PropertyMock(
             return_value='raw')
         disk_utils.populate_image('src', 'dst')
-        mock_dd.assert_called_once_with('src', 'dst')
+        mock_dd.assert_called_once_with('src', 'dst', conv_flags=None)
+        self.assertFalse(mock_cg.called)
+
+    def test_populate_raw_image_with_convert(self, mock_cg, mock_qinfo,
+                                             mock_dd):
+        type(mock_qinfo.return_value).file_format = mock.PropertyMock(
+            return_value='raw')
+        disk_utils.populate_image('src', 'dst', conv_flags='sparse')
+        mock_dd.assert_called_once_with('src', 'dst', conv_flags='sparse')
         self.assertFalse(mock_cg.called)
 
     def test_populate_qcow2_image(self, mock_cg, mock_qinfo, mock_dd):
@@ -1219,11 +1212,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
         mock_execute.assert_has_calls([
             mock.call('sgdisk', '-n', '0:-64MB:0', self.dev,
                       run_as_root=True),
-            mock.call('sync'),
-            mock.call('udevadm', 'settle'),
-            mock.call('partprobe', self.dev, attempts=10, run_as_root=True),
-            mock.call('sgdisk', '-v', self.dev, run_as_root=True),
-
             mock.call('udevadm', 'settle'),
             mock.call('test', '-e', expected_part, attempts=15,
                       check_exit_code=[0], delay_on_retry=True)
@@ -1325,10 +1313,6 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                     '-0', run_as_root=True)
         mock_execute.assert_has_calls([
             parted_call,
-            mock.call('sync'),
-            mock.call('udevadm', 'settle'),
-            mock.call('partprobe', self.dev, attempts=10, run_as_root=True),
-            mock.call('sgdisk', '-v', self.dev, run_as_root=True),
             mock.call('udevadm', 'settle'),
             mock.call('test', '-e', expected_part, attempts=15,
                       check_exit_code=[0], delay_on_retry=True)
@@ -1425,17 +1409,10 @@ class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
                                self.node_uuid, self.dev, config_url)
 
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
-        mock_execute.assert_has_calls([
-            mock.call('parted', '-a', 'optimal', '-s', '--',
-                      self.dev, 'mkpart', 'primary',
-                      'fat32', '-64MiB', '-0',
-                      run_as_root=True),
-            mock.call('sync'),
-            mock.call('udevadm', 'settle'),
-            mock.call('partprobe', self.dev, attempts=10, run_as_root=True),
-            mock.call('sgdisk', '-v', self.dev, run_as_root=True),
-        ])
-
+        mock_execute.assert_called_with('parted', '-a', 'optimal', '-s', '--',
+                                        self.dev, 'mkpart', 'primary',
+                                        'fat32', '-64MiB', '-0',
+                                        run_as_root=True)
         self.assertEqual(2, mock_list_partitions.call_count)
         mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
